.. _Citing_Iris:

===========
Citing Iris
===========

If Iris played an important part in your research then please add us to your
reference list by using one of the recommendations below.

************
BibTeX Entry
************

For example::

 @manual{Iris,
 author = {{Met Office}},
 title = {Iris: A Python package for analysing and visualising meteorological and oceanographic data sets},
 edition = {v1.2},
 year = {2010 - 2013},
 address = {Exeter, Devon },
 url = {http://scitools.org.uk/}
 }


*******************
Downloaded Software
*******************

Suggested format::

 ProductName. Version. ReleaseDate. Publisher. Location. DOIorURL. DownloadDate.

For example::

 Iris. v1.2. 28-Feb-2013. Met Office. UK. https://github.com/SciTools/iris/archive/v1.2.0.tar.gz 01-03-2013


********************
Checked Out Software
********************

Suggested format::

 ProductName. Publisher. URL. CheckoutDate. RepositorySpecificCheckoutInformation.

For example::

 Iris. Met Office. git@github.com:SciTools/iris.git 06-03-2013

.. _How to cite and describe software: https://software.ac.uk/how-cite-software


Reference: [Jackson]_.

.. [Jackson] Jackson, M. 2012. `How to cite and describe software`_. Accessed 06-03-2013.
